@@ -1,11 +1,11 @@
-# @(#)$Id: CPANTesting.pm 370 2012-09-05 16:07:57Z pjf $
+# @(#)$Id: CPANTesting.pm 377 2012-10-20 14:52:32Z pjf $
 
 package CPANTesting;
 
 use strict;
 use warnings;
 
-my $osname = lc $^O; my $uname = qx(uname -a);
+use Sys::Hostname; my $host = lc hostname; my $osname = lc $^O;
 
 sub should_abort {
    return 0;
@@ -22,6 +22,7 @@ sub test_exceptions {
 
 # Private functions
 
+# Is this an attempted install on a CPAN testing platform?
 sub __is_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
                    || ($ENV{PERL5OPT} || q()) =~ m{ CPAN-Reporter }mx) }
 
