@@ -1,10 +1,10 @@
-# @(#)$Id: Label.pm 368 2012-07-09 23:45:58Z pjf $
+# @(#)$Id: Label.pm 377 2012-10-20 14:52:32Z pjf $
 
 package HTML::FormWidgets::Label;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 368 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.15.%d', q$Rev: 377 $ =~ /\d+/gmx );
 use parent qw(HTML::FormWidgets);
 
 __PACKAGE__->mk_accessors( qw(dropcap) );
@@ -22,7 +22,7 @@ sub init {
 sub render_field {
    my ($self, $args) = @_; my $text = $self->text or return;
 
-   ($text = $self->loc( $self->text )) =~ s{ \A \n }{}msx;
+   $text =~ s{ \A \n }{}msx;
 
    if ($self->dropcap) {
       my $markup;
