@@ -1,10 +1,10 @@
-# @(#)$Id: Template.pm 368 2012-07-09 23:45:58Z pjf $
+# @(#)$Id: Template.pm 377 2012-10-20 14:52:32Z pjf $
 
 package HTML::FormWidgets::Template;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 368 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.15.%d', q$Rev: 377 $ =~ /\d+/gmx );
 use parent q(HTML::FormWidgets);
 
 use English qw(-no_match_vars);
@@ -24,7 +24,7 @@ sub render_field {
    my $content = do { local $RS = undef; <$rdr> }; $rdr->close();
    my $id      = $self->id;
 
-   return "[% ref = template_data_${id}; %]\n${content}";
+   return "[% ref = template_data.${id}; %]\n${content}";
 }
 
 1;
